package com.fs.task.mapper;

import com.fs.doctor.domain.Doctor;
import com.fs.task.domain.TaskInfo;
import com.fs.task.dto.PublicIndexDto;
import com.fs.task.dto.TaskDeliveryDto;
import com.fs.task.dto.TaskStatsDTO;
import com.fs.task.vo.GetTaskCompleteStatsVO;
import com.fs.task.vo.TaskSpotCheckUpdateReqVO;
import com.fs.task.vo.audit_Info.AuditTaskInfoVO;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * 任务信息Mapper接口
 *
 * @author fs
 * @date 2026-01-04
 */
public interface TaskInfoMapper {
    /**
     * 查询任务信息
     *
     * @param id 任务信息键
     * @return 任务信息
     */
    public TaskInfo selectTaskInfoById(Long id);

    /**
     * 查询任务信息列表
     *
     * @param taskInfo 任务信息
     * @return 任务信息集合
     */
    public List<TaskInfo> selectTaskInfoList(TaskInfo taskInfo);

    /**
     * 新增任务信息
     *
     * @param taskInfo 任务信息
     * @return 结果
     */
    public int insertTaskInfo(TaskInfo taskInfo);

    /**
     * 修改任务信息
     *
     * @param taskInfo 任务信息
     * @return 结果
     */
    public int updateTaskInfo(TaskInfo taskInfo);

    /**
     * 删除任务信息
     *
     * @param id 任务信息键
     * @return 结果
     */
    public int deleteTaskInfoById(Long id);

    /**
     * 批量删除任务信息
     *
     * @param ids 需要删除的数据键集合
     * @return 结果
     */
    public int deleteTaskInfoByIds(Long[] ids);

    /**
     * 查询审核任务信息视图
     * @param taskId
     * @return
     */
    AuditTaskInfoVO selectAuditTaskInfoVO(Long taskId);

    int updateSpotCheck(TaskSpotCheckUpdateReqVO req);

    List<TaskInfo> selectPendingTasksForGen(@Param("companyId")Long companyId,@Param("deptId") Long departmentId,  @Param("taskTypes")List<Long> taskTypeIds);

    List<TaskStatsDTO> getTaskCompleteStats(GetTaskCompleteStatsVO param);
    BigDecimal getTaskCompleteStatsCount(GetTaskCompleteStatsVO param);

    List<TaskStatsDTO> getTaskCreateStats(GetTaskCompleteStatsVO param);
    BigDecimal getTaskCreateStatsCount(GetTaskCompleteStatsVO param);

    List<TaskInfo> selectTaskInfoByIds(@Param("taskIds") List<Long> taskIds);

    TaskDeliveryDto getTaskDelivery(Long taskId);

    List<PublicIndexDto> getClassroomList(PublicIndexDto publicIndexDto);

    Doctor getTaskDoctorDetail(@Param("id") String id);

    /**
     * 查询任务信息
     *
     * @param id 任务信息键
     * @return 任务信息
     */
    public TaskInfo getTaskByTargetId(@Param("targetId") String targetId);
}
